Folder
======

.. currentmodule:: wwt_data_formats.folder

.. autoclass:: Folder
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Folder.browseable
      ~Folder.children
      ~Folder.cross_validation_lock
      ~Folder.group
      ~Folder.msr_community_id
      ~Folder.msr_component_id
      ~Folder.name
      ~Folder.permission
      ~Folder.rmeta
      ~Folder.searchable
      ~Folder.sub_type
      ~Folder.thumbnail
      ~Folder.type
      ~Folder.url

   .. rubric:: Methods Summary

   .. autosummary::

      ~Folder.add_traits
      ~Folder.apply_to_xml
      ~Folder.class_own_trait_events
      ~Folder.class_own_traits
      ~Folder.class_trait_names
      ~Folder.class_traits
      ~Folder.from_file
      ~Folder.from_text
      ~Folder.from_url
      ~Folder.from_xml
      ~Folder.has_trait
      ~Folder.hold_trait_notifications
      ~Folder.mutate_urls
      ~Folder.notify_change
      ~Folder.observe
      ~Folder.on_trait_change
      ~Folder.set_trait
      ~Folder.setup_instance
      ~Folder.to_xml
      ~Folder.to_xml_string
      ~Folder.trait_defaults
      ~Folder.trait_events
      ~Folder.trait_has_value
      ~Folder.trait_metadata
      ~Folder.trait_names
      ~Folder.trait_values
      ~Folder.traits
      ~Folder.unobserve
      ~Folder.unobserve_all
      ~Folder.walk
      ~Folder.write_xml

   .. rubric:: Attributes Documentation

   .. autoattribute:: browseable
   .. autoattribute:: children
   .. autoattribute:: cross_validation_lock
   .. autoattribute:: group
   .. autoattribute:: msr_community_id
   .. autoattribute:: msr_component_id
   .. autoattribute:: name
   .. autoattribute:: permission
   .. autoattribute:: rmeta
   .. autoattribute:: searchable
   .. autoattribute:: sub_type
   .. autoattribute:: thumbnail
   .. autoattribute:: type
   .. autoattribute:: url

   .. rubric:: Methods Documentation

   .. automethod:: add_traits
   .. automethod:: apply_to_xml
   .. automethod:: class_own_trait_events
   .. automethod:: class_own_traits
   .. automethod:: class_trait_names
   .. automethod:: class_traits
   .. automethod:: from_file
   .. automethod:: from_text
   .. automethod:: from_url
   .. automethod:: from_xml
   .. automethod:: has_trait
   .. automethod:: hold_trait_notifications
   .. automethod:: mutate_urls
   .. automethod:: notify_change
   .. automethod:: observe
   .. automethod:: on_trait_change
   .. automethod:: set_trait
   .. automethod:: setup_instance
   .. automethod:: to_xml
   .. automethod:: to_xml_string
   .. automethod:: trait_defaults
   .. automethod:: trait_events
   .. automethod:: trait_has_value
   .. automethod:: trait_metadata
   .. automethod:: trait_names
   .. automethod:: trait_values
   .. automethod:: traits
   .. automethod:: unobserve
   .. automethod:: unobserve_all
   .. automethod:: walk
   .. automethod:: write_xml
